/*
 Copyright (c) 2011 digitalSTROM.org, Zurich, Switzerland
 
 Author:  Sergey 'Jin' Bostandzhyan <jin@dev.digitalstrom.org>
 
 This file is part of Timed-Events digitalSTROM Server add on.
 
 Timed-Events is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 Timed-Events is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with digitalSTROM Server. If not, see <http://www.gnu.org/licenses/>.
 */
//= require <gettexthelper>
Ext.namespace('TimedEvents', 'TimedEvents.config');

TimedEvents.config.VERSION = '0.2.3';

TimedEvents.config.SubscriptionID = 1337;

var params = 
{
    "domain": "timed-events",
    "locale_data": json_locale_data
};

TimedEvents.config.gt = new Gettext(params);

function _(msgid)
{
    if (TimedEvents.config.gt === undefined) 
    {
        return msgid;
    }
    
    return TimedEvents.config.gt.gettext(msgid);
}


function pad(n)
{
    return n < 10 ? '0' + n : n;
}


TimedEvents.config.Weekdays =
{
	"MO": _("Monday"),
	"TU": _("Tuesday"),
	"WE": _("Wednesday"),
	"TH": _("Thursday"),
	"FR": _("Friday"),
	"SA": _("Saturday"),
	"SU": _("Sunday")
}


TimedEvents.config.groups = 
{
    "VARIABLE": 0,
    "LIGHT": 1,
    "SHADOW": 2,
    "CLIMATE": 3,
    "AUDIO": 4,
    "VIDEO": 5,
    "SECURITY": 6,
    "ACCESS": 7,
    "JOKER": 8,
    "WHITE": 9,
    "DISPLAYS": 10
};

TimedEvents.config.scenes = 
{
    "DEC": {id: 11, name: _("Dim down")},
    "INC": {id: 12, name: _("Dim up")},
    "MIN": {id: 13, name: _("Off")},
    "MAX": {id: 14, name: _("On")},
    "STOP": {id: 15, name: _("Stop")},
    "T0_S0": {id: 0, name: _("Scene") + " 0"},
    "T0_S1": {id: 5, name: _("Scene") + " 1"},
    "T0_S2": {id: 17, name: _("Scene") + " 2"},
    "T0_S3": {id: 18, name: _("Scene") + " 3"},
    "T0_S4": {id: 19, name: _("Scene") + " 4"},
    "AUTO_STANDBY": {id: 64, name: _("Auto Standby")},
    "SIG_BELL": {id: 73, name: _("Bell")},
    "SIG_ALARM": {id: 74, name: _("Alarm")},
    "PANIC": {id: 65, name: _("Panic")},
    "STANDBY": {id: 67, name: _("Standby")},
    "DEEP_OFF": {id: 68, name: _("Deep Off")},
    "PRESENT": {id: 71, name: _("Present")},
    "ABSENT": {id: 72, name: _("Absent")},
    "SLEEPING": {id: 69, name: _("Sleeping")},
    "WAKE_UP": {id: 70, name: _("Wake up")} 
};

TimedEvents.config.sceneStore = new Ext.data.ArrayStore(
{
    fields: ['id', 'displayText']
});

for (var shortName in TimedEvents.config.scenes) 
{
    var rec = new Ext.data.Record(
    {
        id: TimedEvents.config.scenes[shortName].id,
        displayText: TimedEvents.config.scenes[shortName].name
    });
    TimedEvents.config.sceneStore.add(rec);
};


TimedEvents.config.zoneStore = new Ext.data.Store(
{
    sortInfo: 
    {
        field: 'id',
        direction: 'ASC'
    },
    reader: new Ext.data.JsonReader(
    {
        root: "zones",
        fields: [
        {
            name: 'id'
        }, 
        {
            name: 'name'
        }]
    })
});

Ext.Ajax.request(
{
    url: '/json/apartment/getStructure',
    disableCaching: true,
    timeout: 300000,
    method: "GET",
    scope: this,
    success: function(result, request)
    {
        try 
        {
            var jsonData = Ext.util.JSON.decode(result.responseText);
            if (jsonData.ok) 
            {
                var zones = [];
                Ext.each(jsonData.result.apartment.zones, function(zone)
                {
                    if (zone.id !== 0) 
                    {
                        zones.push(
                        {
                            id: zone.id,
                            name: zone.name ? zone.id + " - " +
                            zone.name : zone.id + " - " + _("Zone")
                        });
                    }
                });
                TimedEvents.config.zoneStore.loadData(
                {
                    zones: zones
                });
            }
        } 
        catch (err) 
        {
            Ext.MessageBox.alert(_("Error"), _("Could not load apartment structure") + ": \"" +
            err +
            "\"");
        }
    },
    failure: function(result, request)
    {
        Ext.MessageBox.alert(_("Error"), _("Could not load apartment structure") + ": \"" +
        request.url +
        "\"");
    }
    
});


TimedEvents.ActionPanel = Ext.extend(Ext.Panel, 
{
    constructor: function(config)
    {
        this.parentForm = config.parentForm;
        
        this.changingDesc = new Ext.form.Label(
        {
            scope: this,
            height: 20,
            bodyBorder: false,
            autoEl: 'span',
            cls: 'x-green-text black-text',
            text: _("Value") + ": " + "0%"
        });
        
        this.unitCombo = new Ext.form.ComboBox(
        {
            scope: this,
            editable: false,
            triggerAction: 'all',
            mode: 'local',
            ref: 'unit',
            width: 160,
            fieldLabel: _("Action"),
            forceSelection: true,
            submitValue: false,
            allowBlank: false,
            store: new Ext.data.ArrayStore(
            {
                fields: ['id', 'displayText'],
                data: [['group', _("Group")], ['scene', _("Scene")]]
            }),
            displayField: 'displayText',
            hiddenField: 'id',
            valueField: 'id',
            listeners: 
            {
                select: this.updateDesc.createDelegate(this)
            },
            value: 'group'
        });
        
        this.groupCombo = new Ext.form.ComboBox(
        {
            editable: false,
            mode: 'local',
            ref: 'group',
            width: 160,
            hideLabel: true,
            submitValue: false,
            forceSelection: true,
            triggerAction: 'all',
            allowBlank: false,
            store: new Ext.data.ArrayStore(
            {
                fields: ['id', 'displayText'],
                data: [[TimedEvents.config.groups.LIGHT, _("Light")]]
            }),
            displayField: 'displayText',
            valueField: 'id',
            value: TimedEvents.config.groups.LIGHT
        });
        
        this.sceneCombo = new Ext.form.ComboBox(
        {
            editable: false,
            hidden: false,
            mode: 'local',
            width: 160,
            hideLabel: true,
            submitValue: false,
            forceSelection: true,
            triggerAction: 'all',
            allowBlank: false,
            store: TimedEvents.config.sceneStore,
            displayField: 'displayText',
            valueField: 'id',
            value: TimedEvents.config.scenes.MAX.id
        });
        
        this.value = new Ext.form.SliderField(
        {
            hideLabel: true,
            scope: this,
            width: 160,
            height: 20,
            minValue: 0,
            increment: 1,
            maxValue: 100,
            submitValue: false,
            tipText: function(thumb)
            {
                return String.format('{0}%', thumb.value);
            }
            
        });
        
        this.value.slider.on('changeComplete', function(slider, newVal, thumb)
        {
            this.changingDesc.setText(_("Value") + ": " + newVal + "%");
        }, this);
        
        this.zoneCombo = new Ext.form.ComboBox(
        {
            xtype: 'combo',
            hideLabel: true,
            submitValue: false,
            //lazyInit: true,
            mode: 'local',
            forceSelection: true,
            store: TimedEvents.config.zoneStore,
            emptyText: _("Select zone") +
            "...",
            triggerAction: 'all',
            allowBlank: false,
            typeAhead: true,
            displayField: 'name',
            valueField: 'id',
            hiddenName: 'zone',
            width: 160
        });
        
        this.scenePanel = new Ext.Panel(
        {
            xtype: 'panel',
            scope: this,
            width: 160,
            hidden: true,
            layout: 'form',
            bodyBorder: false,
            items: [this.sceneCombo]
        });
        
        this.valuePanel = new Ext.Panel(
        {
            xtype: 'panel',
            scope: this,
            width: 160,
            layout: 'form',
            bodyBorder: false,
            items: [this.value]
        });
        
        Ext.apply(this, 
        {
            layout: 'table',
            bodyBorder: false,
            hideBorders: true,
            height: 50,
            scope: this,
            autoDestroy: true,
            layoutConfig: 
            {
                columns: 10
            },
            items: [
            // row 1
            {
                xtype: 'box',
                height: 20,
                width: 19
            }, 
            {
                xtype: 'panel',
                height: 20,
                bodyBorder: false,
                autoEl: 'span',
                cls: 'x-green-text black-text',
                html: _("Call") + ":"
            }, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, 
            {
                xtype: 'panel',
                height: 20,
                bodyBorder: false,
                autoEl: 'span',
                cls: 'x-green-text black-text',
                html: _("Zone") + ":"
            }, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, 
            {
                xtype: 'panel',
                height: 20,
                bodyBorder: false,
                autoEl: 'span',
                cls: 'x-green-text black-text',
                html: _("Group") + ":"
            }, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, this.changingDesc, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, 
            
            // row 2
            {
                xtype: 'panel',
                layout: 'form',
                bodyBorder: false,
                colspan: 2,
                items: [this.unitCombo]
            }, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, 
            {
                xtype: 'panel',
                layout: 'form',
                bodyBorder: false,
                items: [this.zoneCombo]
            }, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, 
            {
                xtype: 'panel',
                layout: 'form',
                bodyBorder: false,
                items: [this.groupCombo]
            }, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, 
            {
                xtype: 'panel',
                bodyBorder: false,
                layout: 'fit',
                items: [this.valuePanel, this.scenePanel]
            }, 
            {
                xtype: 'box',
                height: 20,
                width: 10
            }, 
            {
                xtype: 'button',
                text: _("Remove"),
                tooltip: _("Remove this action"),
                scope: this,
                handler: function()
                {
                    this.parentForm.removeAction(this);
                }
                
            }]
        });
        
        TimedEvents.ActionPanel.superclass.constructor.apply(this, arguments);
    },
    updateDesc: function(combo, record, index)
    {
        if (record.get('id') === 'scene') 
        {
            this.changingDesc.setText(_("Scene") + ":");
            this.valuePanel.setVisible(false);
            this.scenePanel.setVisible(true);
        }
        else 
        {
            this.changingDesc.setText(_("Value") + ": " +
            this.value.getValue() +
            "%");
            this.scenePanel.setVisible(false);
            this.valuePanel.setVisible(true);
        }
    },
    
    setAction: function(action)
    {
        if (action.unit == 'group') 
        {
            this.unitCombo.setValue(action.unit);
            this.groupCombo.setValue(action.group);
            this.zoneCombo.setValue(action.zone);
            
            var val = action.value / 255;
            val = val * 100;
            if (val < 0) 
            {
                val = 0;
            }
            else if (val > 100) 
            {
                val = 100;
            }
            this.value.setValue(val);
            
            this.changingDesc.setText(_("Value") + ": " +
            this.value.getValue() +
            "%");
            this.scenePanel.setVisible(false);
            this.valuePanel.setVisible(true);
        }
        else if (action.unit == 'scene') 
        {
            this.unitCombo.setValue(action.unit);
            this.groupCombo.setValue(action.group);
            this.zoneCombo.setValue(action.zone);
            this.sceneCombo.setValue(action.scene);
            
            this.valuePanel.setVisible(false);
            this.scenePanel.setVisible(true);
            this.changingDesc.setText(_("Scene") + ":");
        }
    }
    
});

Ext.reg('actionpanel', TimedEvents.ActionPanel);


TimedEvents.DatePanel = Ext.extend(Ext.Panel, 
{
    constructor: function(config)
    {
        this.parentForm = config.parentForm;
        
        var d = new Date();
        
        Ext.apply(this, 
        {
            layout: 'table',
            scope: this,
            hideBorders: true,
            bodyBorder: false,
            layoutConfig: 
            {
                columns: 3
            },
            items: [
            {
                xtype: 'panel',
                layout: 'form',
                ref: 'date',
                items: [
                {
                    xtype: 'datefield',
                    fieldLabel: _("Timer date"),
                    ref: 'timerDate',
                    format: 'd-m-Y',
                    width: 330,
                    minValue: pad(d.getDate()) + '-' +
                    pad(d.getMonth() + 1) +
                    '-' +
                    d.getFullYear(),
                    allowBlank: false
                }]
            }, 
            {
                xtype: 'box',
                width: 10
            }, 
            {
                xtype: 'button',
                text: _("Remove"),
                scope: this,
                handler: function()
                {
                    this.parentForm.removeDate(this);
                }
                
            }, 
            {
                xtype: 'box',
                height: 5,
                colspan: 3
            }]
        });
        
        TimedEvents.DatePanel.superclass.constructor.apply(this, arguments);
    },
    getValue: function()
    {
        return this.date.timerDate.getValue();
    },
    setDate: function(date)
    {
        this.date.timerDate.setValue(date);
    }
    
});

Ext.reg('datepanel', TimedEvents.DatePanel);

TimedEvents.EventForm = Ext.extend(Ext.FormPanel, 
{
    initComponent: function()
    {
    
        this.actionCount = 0;
        this.dateCount = 0;
        this.loadingStructure = false;
        
        
        NameField = Ext.extend(Ext.form.TextField, 
        {
            initComponent: function()
            {
                Ext.apply(this, 
                {
                    xtype: 'textfield',
                    width: 330,
                    ref: 'timerName',
                    allowBlank: false,
                    fieldLabel: _("Timer name"),
                    padding: 6
                });
                NameField.superclass.initComponent.apply(this, arguments);
            },
            
            validate: function()
            {
                try 
                {
                    var store = this.findParentByType('eventform').findParentByType('window').mainpanel.eventview.eventStore;
                    for (var i = 0; i < store.getCount(); i++) 
                    {
                        if (store.getAt(i).get('name') == this.getValue()) 
                        {
                            return false;
                        }
                    }
                } 
                catch (error) 
                {
                    Ext.MessageBox.alert(error);
                    return false;
                }
                return true;
                
            }
            
        });
        
        this.nameField = new NameField();
        
        this.recurrenceCombo = new Ext.form.ComboBox(
        {
            scope: this,
            editable: false,
            triggerAction: 'all',
            mode: 'local',
            width: 330,
            name: 'recurrence',
            fieldLabel: _("Recurrence"),
            forceSelection: true,
            allowBlank: false,
            store: new Ext.data.ArrayStore(
            {
                fields: ['id', 'displayText'],
                data: [['regular_wk', _("Periodic (weekly)")], ['irregular', _("Irregular")]]
            }),
            displayField: 'displayText',
            valueField: 'id',
            hiddenName: 'recurrence',
            listeners: 
            {
                select: this.showTimeSelection.createDelegate(this)
            },
            value: 'regular_wk'
        });
        
        
        Irregular = new Ext.extend(Ext.Panel, 
        {
            constructor: function(parentForm)
            {
                this.dateCount = 0;
                
                Ext.apply(this, 
                {
                    bodyBorder: false,
                    hidden: true,
                    layout: 'form',
                    //height: 200,
                    ref: 'irregular',
                    autoScroll: true,
                    //scope: this,
                    items: [
                    {
                        xtype: 'button',
                        text: _("Add date"),
                        tooltip: _("Add new date"),
                        scope: this,
                        handler: function()
                        {
                            this.dateHolder.add(new TimedEvents.DatePanel(
                            {
                                parentForm: parentForm
                            }));
                            this.dateHolder.doLayout();
                            this.dateCount++;
                        }
                        
                    }, 
                    {
                        xtype: 'box',
                        hteight: 5
                    }, 
                    {
                        xtype: 'panel',
                        bodyBorder: false,
                        hideBorders: true,
                        ref: 'dateHolder',
                        scope: this
                    }]
                });
                Irregular.superclass.constructor.apply(this, arguments);
            },
            
            addDate: function(date)
            {
                var datePanel = new TimedEvents.DatePanel(
                {
                    parentForm: this
                });
                this.dateHolder.add(datePanel);
                datePanel.setDate(date);
                this.dateHolder.doLayout();
                this.dateCount++;
            }
            
        });
        
        this.irregular = new Irregular(this);
        
        this.MO = new Ext.form.Checkbox(
        {
            name: 'MO',
            boxLabel: _("Monday")
        });
        
        this.TU = new Ext.form.Checkbox(
        {
            name: 'TU',
            boxLabel: _("Tuesday")
        });
        
        this.WE = new Ext.form.Checkbox(
        {
            name: 'WE',
            boxLabel: _("Wednesday")
        });
        
        this.TH = new Ext.form.Checkbox(
        {
            name: 'TH',
            boxLabel: _("Thursday")
        });
        
        this.FR = new Ext.form.Checkbox(
        {
            name: 'FR',
            boxLabel: _("Friday")
        });
        
        this.SA = new Ext.form.Checkbox(
        {
            name: 'SA',
            boxLabel: _("Saturday")
        });
        
        this.SU = new Ext.form.Checkbox(
        {
            name: 'SU',
            boxLabel: _("Sunday")
        });
        
        
        this.periodicWeekly = new Ext.Panel(
        {
            hideBorders: true,
            bodyBorder: false,
            layout: 'table',
            layoutConfig: 
            {
                columns: 3
            },
            items: [
            {
                xtype: 'panel',
                layout: 'form',
                items: [this.MO, this.TU, this.WE]
            }, 
            {
                xtype: 'panel',
                layout: 'form',
                items: [this.TH, this.FR, this.SA]
            }, 
            {
                xtype: 'panel',
                layout: 'form',
                items: [this.SU, 
                {
                    xtype: 'box',
                    height: 50
                }]
            }]
        });
        
        Ext.apply(this, 
        {
            autoScroll: true,
            bodyBorder: false,
            hideBorders: true,
            items: [
            {
                xtype: 'panel',
                padding: 6,
                bodyBorder: false,
                layout: 'form',
                scope: this,
                ref: 'mainPanel',
                items: [
                {
                    xtype: 'fieldset',
                    scope: this,
                    ref: 'timer',
                    title: _("Timer"),
                    items: [this.nameField]
                }, 
                {
                    xtype: 'fieldset',
                    title: _("Timer actions"),
                    bodyBorder: false,
                    //layout: 'fit',
                    //height: 200,
                    ref: 'actionHolder',
                    autoScroll: true,
                    scope: this,
                    items: [
                    {
                        xtype: 'button',
                        
                        text: _("Add action"),
                        tooltip: _("Add new action"),
                        scope: this,
                        handler: function()
                        {
                            this.mainPanel.actionHolder.add(new TimedEvents.ActionPanel(
                            {
                                parentForm: this
                            }));
                            this.mainPanel.actionHolder.doLayout();
                            this.actionCount++;
                        }
                        
                    }]
                }, // actionHolder panel
                {
                    xtype: 'fieldset',
                    scope: this,
                    title: _("Time settings"),
                    ref: 'timeSettings',
                    items: [
                    {
                        xtype: 'timefield',
                        fieldLabel: _("Trigger time"),
                        format: 'H:i:s',
                        ref: 'trigger',
                        width: 330,
                        allowBlank: false
                    }, this.recurrenceCombo, 
                    {
                        xtype: 'box',
                        height: 5
                    }, this.periodicWeekly, this.irregular]
                } // date time fieldset
                ]
            }]
        });
        
        TimedEvents.EventForm.superclass.initComponent.apply(this, arguments);
    },
    
    removeAction: function(action)
    {
        this.mainPanel.actionHolder.remove(action);
        this.mainPanel.actionHolder.doLayout();
        this.actionCount--;
        if (this.actionCount < 0) 
        {
            this.actionCount = 0;
        }
    },
    removeDate: function(date)
    {
        this.irregular.dateHolder.remove(date);
        this.irregular.dateHolder.doLayout();
        this.dateCount--;
        if (this.dateCount < 0) 
        {
            this.dateCount = 0;
        }
    },
    showTimeSelection: function(combo, record, index)
    {
        if (record.get('id') === 'irregular') 
        {
            this.periodicWeekly.setVisible(false);
            this.irregular.setVisible(true);
        }
        else 
        {
            this.irregular.setVisible(false);
            this.irregular.dateHolder.removeAll();
            this.dateCount = 0;
            this.periodicWeekly.setVisible(true);
        }
    },
    
    getActionData: function()
    {
        // process actions
        var counter = 0;
        var actions = {};
        var actionParameters = [];
        var action;
        do 
        {
            action = this.mainPanel.actionHolder.get(counter);
            counter++;
            
            if (action === undefined) 
            {
                break;
            }
            
            if (action.getXType() != 'actionpanel') 
            {
                continue;
            }
            
            
            var unit = action.unitCombo.getValue();
            var group = action.groupCombo.getValue();
            var zone = action.zoneCombo.getValue();
            
            var params = {};
            params.unit = unit;
            params.group = group;
            params.zone = zone;
            
            if (unit === 'group') 
            {
                var val = action.value.getValue() / 100;
                val = val * 255;
                if (val < 0) 
                {
                    val = 0;
                }
                else if (val > 255) 
                {
                    val = 255;
                }
                
                params.value = Math.round(val);
            }
            else if (unit === 'scene') 
            {
                params.scene = action.sceneCombo.getValue();
            }
            
            actionParameters.push(params);
            
        }
        while (action !== undefined);
        
        actions.actions = actionParameters;
        return actions;
    },
    
    getDates: function()
    {
        var counter = 0;
        var dates = [];
        var datepanel;
        do 
        {
            datepanel = this.irregular.dateHolder.get(counter);
            counter++;
            
            if (datepanel === undefined) 
            {
                break;
            }
            
            if (datepanel.getXType() != 'datepanel') 
            {
                continue;
            }
            
            var val = datepanel.getValue();
            
            dates.push(pad(val.getDate()) + '-' +
            pad(val.getMonth() + 1) +
            '-' +
            val.getFullYear());
            
        }
        while (datepanel !== undefined);
        
        return dates;
    },
    
    getWeekdays: function()
    {
        var counter = 0;
        var days = [];
        var panel;
        do 
        {
            panel = this.periodicWeekly.get(counter);
            counter++;
            
            if (panel === undefined) 
            {
                break;
            }
            
            if (panel.getXType() != 'panel') 
            {
                continue;
            }
            
            var ccount = 0;
            var checkbox;
            do 
            {
                checkbox = panel.get(ccount);
                ccount++;
                if (checkbox === undefined) 
                {
                    break;
                }
                
                if (checkbox.getXType() != 'checkbox') 
                {
                    continue;
                }
                
                if (checkbox.getValue() === true) 
                {
                    days.push(checkbox.getName());
                }
                
            }
            while (checkbox !== undefined);
        }
        while (panel !== undefined);
        
        return days;
    },
    
    getRecurrenceData: function()
    {
        var recurrenceObj = {};
        var triggertime = this.mainPanel.timeSettings.trigger.getValue().split(':');
        var d = new Date();
        d.setHours(triggertime[0]);
        d.setMinutes(triggertime[1]);
        d.setSeconds(triggertime[2]);
        
        triggertime = pad(d.getUTCHours()) + ':' + pad(d.getUTCMinutes()) +
        ':' +
        pad(d.getUTCSeconds());
        
        recurrenceObj.triggerTime = triggertime;
        var recurrence = this.recurrenceCombo.getValue();
        recurrenceObj.recurrence = recurrence;
        if (recurrence === 'regular_wk') 
        {
            recurrenceObj.weekdays = this.getWeekdays();
        }
        else if (recurrence === 'irregular') 
        {
            recurrenceObj.dates = this.getDates();
        }
        
        return recurrenceObj;
    },
    
    setParameters: function(name, recurrence, actions)
    {
        this.nameField.setValue(name);
        
        if (recurrence.recurrence == 'regular_wk') 
        {
            var date = new Date();
            var split = recurrence.triggerTime.split(":");
            date.setUTCHours(split[0]);
            date.setUTCMinutes(split[1]);
            date.setUTCSeconds(split[2]);
            this.mainPanel.timeSettings.trigger.setValue(pad(date.getHours()) + ':' + pad(date.getMinutes()) + ':' + pad(date.getSeconds()));
            
            for (var i = 0; i < recurrence.weekdays.length; i++) 
            {
                switch (recurrence.weekdays[i])
                {
                    case "MO":
                        this.MO.setValue(true);
                        break;
                    case "TU":
                        this.TU.setValue(true);
                        break;
                    case "WE":
                        this.WE.setValue(true);
                        break;
                    case "TH":
                        this.TH.setValue(true);
                        break;
                    case "FR":
                        this.FR.setValue(true);
                        break;
                    case "SA":
                        this.SA.setValue(true);
                        break;
                    case "SU":
                        this.SU.setValue(true);
                        break;
                }
            }
        }
        else if (recurrence.recurrence == 'irregular') 
        {
            var date = new Date();
            var split = recurrence.triggerTime.split(":");
            date.setUTCHours(split[0]);
            date.setUTCMinutes(split[1]);
            date.setUTCSeconds(split[2]);
            this.mainPanel.timeSettings.trigger.setValue(pad(date.getHours()) + ':' + pad(date.getMinutes()) + ':' + pad(date.getSeconds()));
            
            this.periodicWeekly.setVisible(false);
            this.irregular.setVisible(true);
            
            for (var i = 0; i < recurrence.dates.length; i++) 
            {
                this.irregular.addDate(recurrence.dates[i]);
            }
            
            this.recurrenceCombo.setValue('irregular');
        }
        
        this.mainPanel.actionHolder.removeAll();
        for (var i = 0; i < actions.actions.length; i++) 
        {
            var actionPanel = new TimedEvents.ActionPanel(
            {
                parentForm: this
            });
            actionPanel.setAction(actions.actions[i]);
            this.mainPanel.actionHolder.add(actionPanel);
            this.actionCount++;
        }
        this.mainPanel.actionHolder.doLayout();
    }
    
});

Ext.reg('eventform', TimedEvents.EventForm);

TimedEvents.EventPanel = Ext.extend(Ext.Panel, 
{
    initComponent: function()
    {
        this.eventStore = new Ext.data.Store(
        {
            fields: ['name', 'time', 'date']
        });
        
        this.EventRecord = Ext.data.Record.create([
        {
            name: "name"
        }, 
        {
            time: "time"
        }, 
        {
            date: "date"
        }, 
        {
            action: "action"
        }]);
        
        this.selectionModel = new Ext.grid.RowSelectionModel(
        {
            singleSelect: true
        });
        
        this.eventGrid = new Ext.grid.GridPanel(
        {
            store: this.eventStore,
            columns: [
            {
                id: 'name',
                header: _("Timed event name"),
                dataIndex: 'name',
                sortable: true
            }, 
            {
                id: 'time',
                header: _("Trigger time"),
                dataIndex: 'time',
                sortable: true
            }, 
            {
                id: 'date',
                header: _("When"),
                dataIndex: 'date',
                sortable: true
            }, 
            {
                id: 'action',
                header: _("Action"),
                dataIndex: 'action',
                sortable: true
            }],
            trackMouseOver: false,
            viewConfig: 
            {
                forceFit: true
            },
            //disableSelection: true,
            bodyBorder: false,
            sm: this.selectionModel
        });
        
        Ext.apply(this, 
        {
            layout: 'fit',
            items: [this.eventGrid]
        });
        
        TimedEvents.EventPanel.superclass.initComponent.apply(this, arguments);
        
        //load stored events from property tree
        this.loadFromPropertyTree();
        
        // subscribe to the timed-events.updateUI event, it is raised if an event has been executed in the dss
        Ext.Ajax.request(
        {
            url: '/json/event/subscribe?name=timed-events.updateUI&subscriptionID=' + TimedEvents.config.SubscriptionID,
            disableCaching: true,
            timeout: 300000,
            method: "GET",
            scope: this,
            success: function(result, request)
            {
                try 
                {
                    var jsonData = Ext.util.JSON.decode(result.responseText);
                    if (jsonData.ok) 
                    {
                        this.listenToSubscription();
                    }
                } 
                catch (err) 
                {
                    Ext.MessageBox.alert(_("Error"), _("Automatic user interface update not possible") + ": \"" +
                    err +
                    "\"");
                }
            },
            failure: function(result, request)
            {
                Ext.MessageBox.alert(_("Error"), _("Automatic user interface update not possible") + ": \"" +
                request.url +
                "\"");
            }
            
        }); //end subscribe
    },
    
    loadFromPropertyTree: function()
    {
        this.eventStore.removeAll();
        Ext.Ajax.request(
        {
            url: '/json/property/getChildren?path=/scripts/timed-events/events',
            disableCaching: true,
            timeout: 300000,
            method: "GET",
            scope: this,
            success: function(result, request)
            {
                try 
                {
                    var jsonData = Ext.util.JSON.decode(result.responseText);
                    if (jsonData.ok) 
                    {
                        var children = jsonData.result;
                        for (var i = 0; i < children.length; i++) 
                        {
                            Ext.Ajax.request(
                            {
                                url: '/json/property/getString?path=/scripts/timed-events/events/' + children[i].name + '/params',
                                disableCaching: true,
                                timeout: 300000,
                                method: "GET",
                                scope: this,
                                success: function(result, request)
                                {
                                    try 
                                    {
                                        var jsonData = Ext.util.JSON.decode(result.responseText);
                                        if (jsonData.ok) 
                                        {
                                            var params = Ext.util.JSON.decode(jsonData.result.value);
                                            this.addEvent(params.name, Ext.util.JSON.decode(decodeURIComponent(params.recurrence)).triggerTime, Ext.util.JSON.decode(decodeURIComponent(params.recurrence)), Ext.util.JSON.decode(decodeURIComponent(params.actions)));
                                        }
                                    } 
                                    catch (err) 
                                    {
                                        Ext.MessageBox.alert(_("Error"), _("Could not load event parameter") + ": \"" +
                                        err +
                                        "\"");
                                    }
                                },
                                failure: function(result, request)
                                {
                                    Ext.MessageBox.alert(_("Error"), _("Could not load event parameter") + ": \"" +
                                    request.url +
                                    "\"");
                                }
                                
                            });
                        }
                    }
                } 
                catch (err) 
                {
                    Ext.MessageBox.alert(_("Error"), _("Could not load events") + ": \"" +
                    err +
                    "\"");
                }
            },
            failure: function(result, request)
            {
                Ext.MessageBox.alert(_("Error"), _("Could not load events") + ": \"" +
                request.url +
                "\"");
            }
            
        });
    },
    
    listenToSubscription: function()
    {
        Ext.Ajax.request(
        {
            url: '/json/event/get?subscriptionID=' + TimedEvents.config.SubscriptionID,
            disableCaching: true,
            timeout: 3600000,
            method: "GET",
            scope: this,
            success: function(result, request)
            {
                try 
                {
                    var jsonData = Ext.util.JSON.decode(result.responseText);
                    if (jsonData.ok) 
                    {
                        this.loadFromPropertyTree();
                        this.listenToSubscription();
                    }
                } 
                catch (err) 
                {
                    Ext.MessageBox.alert(_("Error"), _("Automatic user interface update not possible") + ": \"" +
                    err +
                    "\"" +
                    'catch');
                }
            },
            failure: function(result, request)
            {
                Ext.MessageBox.alert(_("Error"), _("Automatic user interface update not possible") + ": \"" +
                request.url +
                "\"" +
                'failure');
            }
            
        });
    },
    
    addEvent: function(name, time, date, actions)
    {
        var printRecurrenceDate = function(rec)
        {
            var str = "";
            
            if (rec.recurrence === 'regular_wk') 
            {
                for (var i = 0; i < rec.weekdays.length; i++) 
                {
                    str = str + TimedEvents.config.Weekdays[rec.weekdays[i]];
                    if (i < (rec.weekdays.length - 1)) 
                    {
                        str = str + ", ";
                    }
                }
            }
            else if (rec.recurrence === 'irregular') 
            {
                for (var j = 0; j < rec.dates.length; j++) 
                {
                    str = str + rec.dates[j];
                    if (j < (rec.dates.length - 1)) 
                    {
                        str = str + ", ";
                    }
                }
                
            }
            
            return str;
        };
        
        var fromUTC = function(t)
        {
            var d = new Date();
            var split = t.split(':');
            d.setUTCHours(split[0]);
            d.setUTCMinutes(split[1]);
            d.setUTCSeconds(split[2]);
            
            return pad(d.getHours()) + ':' +
            pad(d.getMinutes()) +
            ':' +
            pad(d.getSeconds());
        };
        
        var actionString = '';
        for (i = 0; i < actions.actions.length; i++) 
        {
            var action = actions.actions[i];
            if (action === undefined) 
            {
                break;
            }

            //check if the zones in the action exists, otherwise
	    //delete action
            if(TimedEvents.config.zoneStore.getById(action.zone) == undefined)
	    {
                Ext.Ajax.request(
		{
		   url: '/json/event/raise',
		   scope: this,
		   params:
		   {
		       name: 'timed-events.delete',
		       parameter: 'eventname='+name
		   },
		   method: 'GET',
		});
                return;
	    }
            
            if (action.unit === 'scene') 
            {
                //search for scene number + name
                for (var shortName in TimedEvents.config.scenes) 
                {
                    if (TimedEvents.config.scenes[shortName].id == action.scene) 
                    {
                        actionString = actionString + _("Scene") + ' ' + TimedEvents.config.scenes[shortName].name + ' ' + _("in Zone") + ' ' + TimedEvents.config.zoneStore.getById(action.zone).get('name') + '<br>';
                        break;
                    }
                }
            }
            else if (action.unit === 'group') 
            {
                actionString = actionString + _("Value") + ' ' + action.value + ' ' + _("in Zone") + ' ' + TimedEvents.config.zoneStore.getById(action.zone).get('name') + '<br>';
            }
        }
        
        
        var rec = new this.EventRecord(
        {
            name: name,
            time: fromUTC(time),
            date: printRecurrenceDate(date),
            action: actionString
        });
        this.eventStore.add(rec);
    },
    
    getSelectedName: function()
    {
        try 
        {
            return this.selectionModel.getSelected().get('name');
        } 
        catch (e) 
        {
            Ext.MessageBox.alert(_("Error"), _("please create at least one event before deleting or modifying"));
        }
    },
    
    removeSelected: function()
    {
        this.eventStore.remove(this.selectionModel.getSelected());
    }
    
});

Ext.reg('eventview', TimedEvents.EventPanel);

TimedEvents.MainPanel = Ext.extend(Ext.Panel, 
{
    initComponent: function()
    {
        Ext.apply(this, 
        {
            layout: 'border',
            title: _("Configure timed events"),
            items: [
            /*{
             xtype: 'panel',
             region: 'north',
             autoEl: 'span',
             cls: 'x-green-text black-text',
             padding: 4,
             bodyBorder: false,
             html: _("This add-on allows you to configure timed events.")
             },*/
            {
                xtype: 'eventview',
                ref: 'eventview',
                region: 'center'
            }],
            bbar: 
            {
                xtype: 'toolbar',
                items: [
                {
                    xtype: 'tbtext',
                    cls: 'x-black-text x-text-align-left x-text-cut',
                    text: _("Version") + ': ' + TimedEvents.config.VERSION
                }, 
                {
                    xtype: 'tbseparator',
                    width: 8
                }, '->', 
                {
                    xtype: 'button',
                    text: _("Delete timed event"),
                    iconCls: 'icon-delete-action',
                    handler: function()
                    {
                        Ext.Ajax.request(
                        {
                            url: '/json/event/raise',
                            scope: this,
                            params: 
                            {
                                name: 'timed-events.delete',
                                parameter: 'eventname=' + this.findParentByType('timedeventsmainpanel').eventview.getSelectedName()
                            },
                            method: 'GET',
                            scope: this,
                            success: function(action)
                            {
                                try 
                                {
                                    var jsonData = Ext.util.JSON.decode(action.responseText);
                                    if (jsonData.ok) 
                                    {
                                        this.findParentByType('timedeventsmainpanel').eventview.removeSelected();
                                    }
                                    else 
                                    {
                                        Ext.Msg.alert(_("Error"), _("Failed to delete event"));
                                    }
                                } 
                                catch (error) 
                                {
                                    Ext.Msg.alert(_("Error"), _("Failed to delete event"));
                                }
                            },
                            failure: function(action)
                            {
                                Ext.Msg.alert(_("Error"), _("Failed to delete event, please check if dSS is still running"));
                            }
                            
                        });
                    }
                    
                }, 
                {
                    xtype: 'button',
                    text: _("Modify timed event"),
                    iconCls: 'icon-edit-action',
                    handler: function()
                    {
                        this.findParentByType('timedeventsmainpanel').eventview.getSelectedName(); //check if something is selected
                        Ext.Ajax.request(
                        {
                            url: '/json/property/getString?path=/scripts/timed-events/events/' + this.findParentByType('timedeventsmainpanel').eventview.getSelectedName() + '/params',
                            method: "GET",
                            scope: this,
                            success: function(result, request)
                            {
                                try 
                                {
                                    var jsonData = Ext.util.JSON.decode(result.responseText);
                                    if (jsonData.ok) 
                                    {
                                        var params = Ext.util.JSON.decode(jsonData.result.value);
                                        //delete existing event
                                        Ext.Ajax.request(
                                        {
                                            url: '/json/event/raise',
                                            params: 
                                            {
                                                name: 'timed-events.delete',
                                                parameter: 'eventname=' + this.findParentByType('timedeventsmainpanel').eventview.getSelectedName()
                                            },
                                            method: 'GET',
                                            scope: this,
                                            success: function(action)
                                            {
                                                try 
                                                {
                                                    var jsonData = Ext.util.JSON.decode(action.responseText);
                                                    if (jsonData.ok) 
                                                    {
                                                        this.findParentByType('timedeventsmainpanel').eventview.removeSelected();
                                                    }
                                                    else 
                                                    {
                                                        Ext.Msg.alert(_("Error"), _("Failed to modify event"));
                                                    }
                                                } 
                                                catch (error) 
                                                {
                                                    Ext.Msg.alert(_("Error"), _("Failed to modify event"));
                                                }
                                            },
                                            failure: function(action)
                                            {
                                                Ext.Msg.alert(_("Error"), _("Failed to modify event, please check if dSS is still running"));
                                            }
                                            
                                        });
                                        
                                        //open form to modify existing data
                                        var win = new Ext.Window(
                                        {
                                            title: _("Configure timed events"),
                                            layout: 'fit',
                                            hideBorders: true,
                                            height: 500,
                                            width: 900,
                                            minHeight: 400,
                                            minWidth: 800,
                                            autoScroll: true,
                                            closable: false,
                                            scope: this,
                                            mainpanel: this.findParentByType('timedeventsmainpanel'),
                                            items: [
                                            {
                                                xtype: 'eventform',
                                                ref: 'eventForm'
                                            }],
                                            buttons: [
                                            {
                                                text: _("Cancel"),
                                                scope: this,
                                                handler: function()
                                                {
                                                    win.setParameters(params.name, Ext.util.JSON.decode(decodeURIComponent(params.recurrence)), Ext.util.JSON.decode(decodeURIComponent(params.actions)));
                                                    win.activateTimer();
                                                }
                                                
                                            }, 
                                            {
                                                text: _("Save and activate"),
                                                scope: this,
                                                handler: function()
                                                {
                                                    win.activateTimer();
                                                }
                                                
                                            }],
                                            
                                            setParameters: function(name, recurrence, actions)
                                            {
                                                this.eventForm.setParameters(name, recurrence, actions);
                                            },
                                            
                                            activateTimer: function()
                                            {
                                                if (!this.eventForm.nameField.validate()) 
                                                {
                                                    Ext.MessageBox.alert(_("Error"), _("Please choose a unique name"));
                                                    return;
                                                }
                                                
                                                
                                                if (!this.eventForm.getForm().isValid()) 
                                                {
                                                    Ext.MessageBox.alert(_("Error"), _("Please fill out all mandatory fields"));
                                                    return;
                                                }
                                                
                                                if (this.eventForm.actionCount === 0) 
                                                {
                                                    Ext.MessageBox.alert(_("Error"), _("Please add at least one action"));
                                                    return;
                                                }
                                                
                                                var recurrence = this.eventForm.getRecurrenceData();
                                                
                                                if ((recurrence.recurrence === 'irregular') &&
                                                (recurrence.dates.length === 0)) 
                                                {
                                                    Ext.MessageBox.alert(_("Error"), _("The irregular recurrence requires at least one date selection"));
                                                    return;
                                                }
                                                
                                                if ((recurrence.recurrence === 'regular_wk') &&
                                                (recurrence.weekdays.length === 0)) 
                                                {
                                                    Ext.MessageBox.alert(_("Error"), _("The periodic recurrence requires at least one weekday selection"));
                                                    return;
                                                }
                                                
                                                var name = this.eventForm.mainPanel.timer.timerName.getValue();
                                                var timername = 'timername=' + name + ';';
                                                
                                                var actions = this.eventForm.getActionData();
                                                
                                                var a_param = 'actions=' +
                                                encodeURIComponent(Ext.encode(actions)) +
                                                ';';
                                                var r_param = 'recurrence=' +
                                                encodeURIComponent(Ext.encode(recurrence));
                                                
                                                Ext.Ajax.request(
                                                {
                                                    url: '/json/event/raise',
                                                    method: 'GET',
                                                    scope: this,
                                                    params: 
                                                    {
                                                        name: 'timed-events.add',
                                                        parameter: timername + a_param + r_param
                                                    },
                                                    success: function(action)
                                                    {
                                                        try 
                                                        {
                                                            var jsonData = Ext.util.JSON.decode(action.responseText);
                                                            if (jsonData.ok) 
                                                            {
                                                                this.mainpanel.eventview.addEvent(name, recurrence.triggerTime, recurrence, actions);
                                                                
                                                                this.close();
                                                                return;
                                                            }
                                                            else 
                                                            {
                                                                Ext.Msg.alert(_("Error"), _("Failed to add timer"));
                                                            }
                                                        } 
                                                        catch (error) 
                                                        {
                                                            Ext.Msg.alert(_("Error"), _("Failed to add timer"));
                                                        }
                                                    },
                                                    failure: function(action)
                                                    {
                                                        Ext.Msg.alert(_("Error"), _("Failed to add timer, " +
                                                        "please check if dSS is " +
                                                        "still running"));
                                                    }
                                                    
                                                });
                                            }
                                            
                                            // all ok, submit form 
                                        });
                                        
                                        win.on('beforedestroy', function()
                                        {
                                            this.findParentByType('timedeventsmainpanel').el.unmask();
                                            this.enable();
                                        }, this);
                                        
                                        win.setParameters(params.name, Ext.util.JSON.decode(decodeURIComponent(params.recurrence)), Ext.util.JSON.decode(decodeURIComponent(params.actions)));
                                        
                                        this.disable();
                                        this.findParentByType('timedeventsmainpanel').el.mask();
                                        win.show(this);
                                    }
                                } 
                                
                                catch (err) 
                                {
                                    Ext.MessageBox.alert(_("Error"), _("Could not load event parameter") + ": \"" +
                                    err +
                                    "\"");
                                }
                            },
                            failure: function(result, request)
                            {
                                Ext.MessageBox.alert(_("Error"), _("Could not load event parameter") + ": \"" +
                                request.url +
                                "\"");
                            }
                            
                        });
                    }
                    
                }, 
                {
                    xtype: 'button',
                    text: _("Add new timed event"),
                    ref: 'addTimedEventButton',
                    iconCls: 'icon-add-action',
                    handler: function()
                    {
                        var win = new Ext.Window(
                        {
                            title: _("Configure timed events"),
                            layout: 'fit',
                            hideBorders: true,
                            height: 500,
                            width: 900,
                            minHeight: 400,
                            minWidth: 800,
                            autoScroll: true,
                            closable: false,
                            scope: this,
                            mainpanel: this.findParentByType('timedeventsmainpanel'),
                            items: [
                            {
                                xtype: 'eventform',
                                ref: 'eventForm'
                            }],
                            buttons: [
                            {
                                text: _("Cancel"),
                                scope: this,
                                handler: function()
                                {
                                    win.close();
                                    this.enable();
                                    this.findParentByType('timedeventsmainpanel').el.unmask();
                                }
                                
                            }, 
                            {
                                text: _("Save and activate"),
                                scope: this,
                                handler: function()
                                {
                                    win.activateTimer();
                                }
                                
                            }],
                            activateTimer: function()
                            {
                                if (!this.eventForm.nameField.validate()) 
                                {
                                    Ext.MessageBox.alert(_("Error"), _("Please choose a unique name"));
                                    return;
                                }
                                
                                
                                if (!this.eventForm.getForm().isValid()) 
                                {
                                    Ext.MessageBox.alert(_("Error"), _("Please fill out all mandatory fields"));
                                    return;
                                }
                                
                                if (this.eventForm.actionCount === 0) 
                                {
                                    Ext.MessageBox.alert(_("Error"), _("Please add at least one action"));
                                    return;
                                }
                                
                                var recurrence = this.eventForm.getRecurrenceData();
                                
                                if ((recurrence.recurrence === 'irregular') &&
                                (recurrence.dates.length === 0)) 
                                {
                                    Ext.MessageBox.alert(_("Error"), _("The irregular recurrence requires at least one date selection"));
                                    return;
                                }
                                
                                if ((recurrence.recurrence === 'regular_wk') &&
                                (recurrence.weekdays.length === 0)) 
                                {
                                    Ext.MessageBox.alert(_("Error"), _("The periodic recurrence requires at least one weekday selection"));
                                    return;
                                }
                                
                                var name = this.eventForm.mainPanel.timer.timerName.getValue();
                                var timername = 'timername=' + name + ';';
                                
                                var actions = this.eventForm.getActionData();
                                
                                var a_param = 'actions=' +
                                encodeURIComponent(Ext.encode(actions)) +
                                ';';
                                var r_param = 'recurrence=' +
                                encodeURIComponent(Ext.encode(recurrence));
                                
                                Ext.Ajax.request(
                                {
                                    url: '/json/event/raise',
                                    method: 'GET',
                                    scope: this,
                                    params: 
                                    {
                                        name: 'timed-events.add',
                                        parameter: timername + a_param + r_param
                                    },
                                    success: function(action)
                                    {
                                        try 
                                        {
                                            var jsonData = Ext.util.JSON.decode(action.responseText);
                                            if (jsonData.ok) 
                                            {
                                                this.mainpanel.eventview.addEvent(name, recurrence.triggerTime, recurrence, actions);
                                                
                                                this.close();
                                                return;
                                            }
                                            else 
                                            {
                                                Ext.Msg.alert(_("Error"), _("Failed to add timer"));
                                            }
                                        } 
                                        catch (error) 
                                        {
                                            Ext.Msg.alert(_("Error"), _("Failed to add timer"));
                                        }
                                    },
                                    failure: function(action)
                                    {
                                        Ext.Msg.alert(_("Error"), _("Failed to add timer, " +
                                        "please check if dSS is " +
                                        "still running"));
                                    }
                                    
                                });
                            }
                            
                            // all ok, submit form 
                        });
                        
                        win.on('beforedestroy', function()
                        {
                            this.findParentByType('timedeventsmainpanel').el.unmask();
                            this.enable();
                        }, this);
                        
                        this.disable();
                        this.findParentByType('timedeventsmainpanel').el.mask();
                        win.show(this);
                    }
                    
                }]
            }
        });
        
        TimedEvents.MainPanel.superclass.initComponent.apply(this, arguments);
    }
    
});

Ext.reg('timedeventsmainpanel', TimedEvents.MainPanel);

Ext.onReady(function()
{
    Ext.get('start').remove();
    
    Ext.Ajax.request(
    {
        url: '/json/system/login',
        params: 
        {
            user: 'dssadmin',
            password: 'dssadmin'
        },
        scope: this,
        method: 'GET',
        disableCaching: true,
        success: function(response, options)
        {
            try 
            {
                if (response.responseText.length == 0) 
                {
                    Ext.MessageBox.alert(_("Error"), _("No response from dSS. Check if the dSS is running and reload this page again."));
                    return;
                }
                
                var jsonData = Ext.util.JSON.decode(response.responseText);
                if (jsonData.ok) 
                {
                    this.viewport = new Ext.Viewport(
                    {
                        hideBorders: true,
                        layout: 'border',
                        items: [
                        {
                            xtype: 'box',
                            region: 'north',
                            height: 80,
                            autoEl: 
                            {
                                tag: 'div',
                                html: '<a href="http://digitalstrom.org/" alt="' +
                                _("visit digitalSTROM.org") +
                                '"><img id="logo" src="images/ds_logo.gif"' +
                                'alt="dS-Logo"></a>' +
                                '<h1><a href="http://digitalstrom.org/"' +
                                ' alt="visit digitalSTROM.org">' +
                                _("digitalSTROM Server - Timed Events") +
                                '</a></h1>'
                            }
                        }, 
                        {
                            region: 'center',
                            xtype: 'timedeventsmainpanel'
                        }]
                    });
                }
                else 
                    Ext.MessageBox.alert(_('Error'), _('Could not log in') + ': ' + jsonData.message);
            } 
            catch (err) 
            {
                Ext.MessageBox.alert(_('Error'), _('Could not log in') + ': ' + err);
            }
        },
        failure: function(response, options)
        {
            Ext.MessageBox.alert(_('Error'), _('Could not send login command to dSS'));
        }
        
    });
});
